# coding: utf-8

"""
    Velo Payments APIs

    ## Terms and Definitions  Throughout this document and the Velo platform the following terms are used:  * **Payor.** An entity (typically a corporation) which wishes to pay funds to one or more payees via a payout. * **Payee.** The recipient of funds paid out by a payor. * **Payment.** A single transfer of funds from a payor to a payee. * **Payout.** A batch of Payments, typically used by a payor to logically group payments (e.g. by business day). Technically there need be no relationship between the payments in a payout - a single payout can contain payments to multiple payees and/or multiple payments to a single payee. * **Sandbox.** An integration environment provided by Velo Payments which offers a similar API experience to the production environment, but all funding and payment events are simulated, along with many other services such as OFAC sanctions list checking.  ## Overview  The Velo Payments API allows a payor to perform a number of operations. The following is a list of the main capabilities in a natural order of execution:  * Authenticate with the Velo platform * Maintain a collection of payees * Query the payor’s current balance of funds within the platform and perform additional funding * Issue payments to payees * Query the platform for a history of those payments  This document describes the main concepts and APIs required to get up and running with the Velo Payments platform. It is not an exhaustive API reference. For that, please see the separate Velo Payments API Reference.  ## API Considerations  The Velo Payments API is REST based and uses the JSON format for requests and responses.  Most calls are secured using OAuth 2 security and require a valid authentication access token for successful operation. See the Authentication section for details.  Where a dynamic value is required in the examples below, the {token} format is used, suggesting that the caller needs to supply the appropriate value of the token in question (without including the { or } characters).  Where curl examples are given, the –d @filename.json approach is used, indicating that the request body should be placed into a file named filename.json in the current directory. Each of the curl examples in this document should be considered a single line on the command-line, regardless of how they appear in print.  ## Authenticating with the Velo Platform  Once Velo backoffice staff have added your organization as a payor within the Velo platform sandbox, they will create you a payor Id, an API key and an API secret and share these with you in a secure manner.  You will need to use these values to authenticate with the Velo platform in order to gain access to the APIs. The steps to take are explained in the following:  create a string comprising the API key (e.g. 44a9537d-d55d-4b47-8082-14061c2bcdd8) and API secret (e.g. c396b26b-137a-44fd-87f5-34631f8fd529) with a colon between them. E.g. 44a9537d-d55d-4b47-8082-14061c2bcdd8:c396b26b-137a-44fd-87f5-34631f8fd529  base64 encode this string. E.g.: NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==  create an HTTP **Authorization** header with the value set to e.g. Basic NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==  perform the Velo authentication REST call using the HTTP header created above e.g. via curl:  ```   curl -X POST \\   -H \"Content-Type: application/json\" \\   -H \"Authorization: Basic NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==\" \\   'https://api.sandbox.velopayments.com/v1/authenticate?grant_type=client_credentials' ```  If successful, this call will result in a **200** HTTP status code and a response body such as:  ```   {     \"access_token\":\"19f6bafd-93fd-4747-b229-00507bbc991f\",     \"token_type\":\"bearer\",     \"expires_in\":1799,     \"scope\":\"...\"   } ``` ## API access following authentication Following successful authentication, the value of the access_token field in the response (indicated in green above) should then be presented with all subsequent API calls to allow the Velo platform to validate that the caller is authenticated.  This is achieved by setting the HTTP Authorization header with the value set to e.g. Bearer 19f6bafd-93fd-4747-b229-00507bbc991f such as the curl example below:  ```   -H \"Authorization: Bearer 19f6bafd-93fd-4747-b229-00507bbc991f \" ```  If you make other Velo API calls which require authorization but the Authorization header is missing or invalid then you will get a **401** HTTP status response.   # noqa: E501

    The version of the OpenAPI document: 2.26.124
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class PaymentEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_type': 'str',
        'event_id': 'str',
        'created_at': 'datetime',
        'payment_id': 'str',
        'payout_payor_ids': 'PayoutPayorIds',
        'payor_payment_id': 'str'
    }

    attribute_map = {
        'source_type': 'sourceType',
        'event_id': 'eventId',
        'created_at': 'createdAt',
        'payment_id': 'paymentId',
        'payout_payor_ids': 'payoutPayorIds',
        'payor_payment_id': 'payorPaymentId'
    }

    def __init__(self, source_type=None, event_id=None, created_at=None, payment_id=None, payout_payor_ids=None, payor_payment_id=None):  # noqa: E501
        """PaymentEvent - a model defined in OpenAPI"""  # noqa: E501

        self._source_type = None
        self._event_id = None
        self._created_at = None
        self._payment_id = None
        self._payout_payor_ids = None
        self._payor_payment_id = None
        self.discriminator = None

        self.source_type = source_type
        self.event_id = event_id
        self.created_at = created_at
        self.payment_id = payment_id
        if payout_payor_ids is not None:
            self.payout_payor_ids = payout_payor_ids
        if payor_payment_id is not None:
            self.payor_payment_id = payor_payment_id

    @property
    def source_type(self):
        """Gets the source_type of this PaymentEvent.  # noqa: E501

        OA3 Schema type name for the source info which is used as the discriminator value to ensure that data binding works correctly  # noqa: E501

        :return: The source_type of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this PaymentEvent.

        OA3 Schema type name for the source info which is used as the discriminator value to ensure that data binding works correctly  # noqa: E501

        :param source_type: The source_type of this PaymentEvent.  # noqa: E501
        :type: str
        """
        if source_type is None:
            raise ValueError("Invalid value for `source_type`, must not be `None`")  # noqa: E501

        self._source_type = source_type

    @property
    def event_id(self):
        """Gets the event_id of this PaymentEvent.  # noqa: E501

        UUID id of the source event in the Velo platform  # noqa: E501

        :return: The event_id of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this PaymentEvent.

        UUID id of the source event in the Velo platform  # noqa: E501

        :param event_id: The event_id of this PaymentEvent.  # noqa: E501
        :type: str
        """
        if event_id is None:
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def created_at(self):
        """Gets the created_at of this PaymentEvent.  # noqa: E501

        ISO8601 timestamp indicating when the source event was created  # noqa: E501

        :return: The created_at of this PaymentEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PaymentEvent.

        ISO8601 timestamp indicating when the source event was created  # noqa: E501

        :param created_at: The created_at of this PaymentEvent.  # noqa: E501
        :type: datetime
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def payment_id(self):
        """Gets the payment_id of this PaymentEvent.  # noqa: E501

        ID of this payment within the Velo platform  # noqa: E501

        :return: The payment_id of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this PaymentEvent.

        ID of this payment within the Velo platform  # noqa: E501

        :param payment_id: The payment_id of this PaymentEvent.  # noqa: E501
        :type: str
        """
        if payment_id is None:
            raise ValueError("Invalid value for `payment_id`, must not be `None`")  # noqa: E501

        self._payment_id = payment_id

    @property
    def payout_payor_ids(self):
        """Gets the payout_payor_ids of this PaymentEvent.  # noqa: E501


        :return: The payout_payor_ids of this PaymentEvent.  # noqa: E501
        :rtype: PayoutPayorIds
        """
        return self._payout_payor_ids

    @payout_payor_ids.setter
    def payout_payor_ids(self, payout_payor_ids):
        """Sets the payout_payor_ids of this PaymentEvent.


        :param payout_payor_ids: The payout_payor_ids of this PaymentEvent.  # noqa: E501
        :type: PayoutPayorIds
        """

        self._payout_payor_ids = payout_payor_ids

    @property
    def payor_payment_id(self):
        """Gets the payor_payment_id of this PaymentEvent.  # noqa: E501

        ID of this payment in the payors system  # noqa: E501

        :return: The payor_payment_id of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._payor_payment_id

    @payor_payment_id.setter
    def payor_payment_id(self, payor_payment_id):
        """Sets the payor_payment_id of this PaymentEvent.

        ID of this payment in the payors system  # noqa: E501

        :param payor_payment_id: The payor_payment_id of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._payor_payment_id = payor_payment_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
