# coding: utf-8

"""
    Velo Payments APIs

    ## Terms and Definitions  Throughout this document and the Velo platform the following terms are used:  * **Payor.** An entity (typically a corporation) which wishes to pay funds to one or more payees via a payout. * **Payee.** The recipient of funds paid out by a payor. * **Payment.** A single transfer of funds from a payor to a payee. * **Payout.** A batch of Payments, typically used by a payor to logically group payments (e.g. by business day). Technically there need be no relationship between the payments in a payout - a single payout can contain payments to multiple payees and/or multiple payments to a single payee. * **Sandbox.** An integration environment provided by Velo Payments which offers a similar API experience to the production environment, but all funding and payment events are simulated, along with many other services such as OFAC sanctions list checking.  ## Overview  The Velo Payments API allows a payor to perform a number of operations. The following is a list of the main capabilities in a natural order of execution:  * Authenticate with the Velo platform * Maintain a collection of payees * Query the payor’s current balance of funds within the platform and perform additional funding * Issue payments to payees * Query the platform for a history of those payments  This document describes the main concepts and APIs required to get up and running with the Velo Payments platform. It is not an exhaustive API reference. For that, please see the separate Velo Payments API Reference.  ## API Considerations  The Velo Payments API is REST based and uses the JSON format for requests and responses.  Most calls are secured using OAuth 2 security and require a valid authentication access token for successful operation. See the Authentication section for details.  Where a dynamic value is required in the examples below, the {token} format is used, suggesting that the caller needs to supply the appropriate value of the token in question (without including the { or } characters).  Where curl examples are given, the –d @filename.json approach is used, indicating that the request body should be placed into a file named filename.json in the current directory. Each of the curl examples in this document should be considered a single line on the command-line, regardless of how they appear in print.  ## Authenticating with the Velo Platform  Once Velo backoffice staff have added your organization as a payor within the Velo platform sandbox, they will create you a payor Id, an API key and an API secret and share these with you in a secure manner.  You will need to use these values to authenticate with the Velo platform in order to gain access to the APIs. The steps to take are explained in the following:  create a string comprising the API key (e.g. 44a9537d-d55d-4b47-8082-14061c2bcdd8) and API secret (e.g. c396b26b-137a-44fd-87f5-34631f8fd529) with a colon between them. E.g. 44a9537d-d55d-4b47-8082-14061c2bcdd8:c396b26b-137a-44fd-87f5-34631f8fd529  base64 encode this string. E.g.: NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==  create an HTTP **Authorization** header with the value set to e.g. Basic NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==  perform the Velo authentication REST call using the HTTP header created above e.g. via curl:  ```   curl -X POST \\   -H \"Content-Type: application/json\" \\   -H \"Authorization: Basic NDRhOTUzN2QtZDU1ZC00YjQ3LTgwODItMTQwNjFjMmJjZGQ4OmMzOTZiMjZiLTEzN2EtNDRmZC04N2Y1LTM0NjMxZjhmZDUyOQ==\" \\   'https://api.sandbox.velopayments.com/v1/authenticate?grant_type=client_credentials' ```  If successful, this call will result in a **200** HTTP status code and a response body such as:  ```   {     \"access_token\":\"19f6bafd-93fd-4747-b229-00507bbc991f\",     \"token_type\":\"bearer\",     \"expires_in\":1799,     \"scope\":\"...\"   } ``` ## API access following authentication Following successful authentication, the value of the access_token field in the response (indicated in green above) should then be presented with all subsequent API calls to allow the Velo platform to validate that the caller is authenticated.  This is achieved by setting the HTTP Authorization header with the value set to e.g. Bearer 19f6bafd-93fd-4747-b229-00507bbc991f such as the curl example below:  ```   -H \"Authorization: Bearer 19f6bafd-93fd-4747-b229-00507bbc991f \" ```  If you make other Velo API calls which require authorization but the Authorization header is missing or invalid then you will get a **401** HTTP status response.   # noqa: E501

    The version of the OpenAPI document: 2.26.124
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdateWebhookRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'webhook_url': 'str',
        'authorization_header': 'str',
        'enabled': 'bool',
        'categories': 'list[Category]'
    }

    attribute_map = {
        'webhook_url': 'webhookUrl',
        'authorization_header': 'authorizationHeader',
        'enabled': 'enabled',
        'categories': 'categories'
    }

    def __init__(self, webhook_url=None, authorization_header=None, enabled=None, categories=None):  # noqa: E501
        """UpdateWebhookRequest - a model defined in OpenAPI"""  # noqa: E501

        self._webhook_url = None
        self._authorization_header = None
        self._enabled = None
        self._categories = None
        self.discriminator = None

        if webhook_url is not None:
            self.webhook_url = webhook_url
        self.authorization_header = authorization_header
        if enabled is not None:
            self.enabled = enabled
        self.categories = categories

    @property
    def webhook_url(self):
        """Gets the webhook_url of this UpdateWebhookRequest.  # noqa: E501

        the webhook URL to use.  # noqa: E501

        :return: The webhook_url of this UpdateWebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """Sets the webhook_url of this UpdateWebhookRequest.

        the webhook URL to use.  # noqa: E501

        :param webhook_url: The webhook_url of this UpdateWebhookRequest.  # noqa: E501
        :type: str
        """
        if webhook_url is not None and len(webhook_url) > 2000:
            raise ValueError("Invalid value for `webhook_url`, length must be less than or equal to `2000`")  # noqa: E501
        if webhook_url is not None and len(webhook_url) < 6:
            raise ValueError("Invalid value for `webhook_url`, length must be greater than or equal to `6`")  # noqa: E501

        self._webhook_url = webhook_url

    @property
    def authorization_header(self):
        """Gets the authorization_header of this UpdateWebhookRequest.  # noqa: E501

        the authorization header to include with the notification.  # noqa: E501

        :return: The authorization_header of this UpdateWebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._authorization_header

    @authorization_header.setter
    def authorization_header(self, authorization_header):
        """Sets the authorization_header of this UpdateWebhookRequest.

        the authorization header to include with the notification.  # noqa: E501

        :param authorization_header: The authorization_header of this UpdateWebhookRequest.  # noqa: E501
        :type: str
        """
        if authorization_header is not None and len(authorization_header) > 1000:
            raise ValueError("Invalid value for `authorization_header`, length must be less than or equal to `1000`")  # noqa: E501
        if authorization_header is not None and len(authorization_header) < 4:
            raise ValueError("Invalid value for `authorization_header`, length must be greater than or equal to `4`")  # noqa: E501
        if authorization_header is not None and not re.search(r'.*', authorization_header):  # noqa: E501
            raise ValueError(r"Invalid value for `authorization_header`, must be a follow pattern or equal to `/.*/`")  # noqa: E501

        self._authorization_header = authorization_header

    @property
    def enabled(self):
        """Gets the enabled of this UpdateWebhookRequest.  # noqa: E501

        whether the webhook is enabled.  # noqa: E501

        :return: The enabled of this UpdateWebhookRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this UpdateWebhookRequest.

        whether the webhook is enabled.  # noqa: E501

        :param enabled: The enabled of this UpdateWebhookRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def categories(self):
        """Gets the categories of this UpdateWebhookRequest.  # noqa: E501

        The notification categories to enable.  # noqa: E501

        :return: The categories of this UpdateWebhookRequest.  # noqa: E501
        :rtype: list[Category]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this UpdateWebhookRequest.

        The notification categories to enable.  # noqa: E501

        :param categories: The categories of this UpdateWebhookRequest.  # noqa: E501
        :type: list[Category]
        """

        self._categories = categories

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWebhookRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
